@@ -1,2 +1,2 @@
 from pyemission.pyemission import Car, GV
-from pyemission import utility_functions
\ No newline at end of file
+from pyemission.util import Util
\ No newline at end of file
